@@ -11,7 +11,7 @@ BEGIN { $fields = {
 	"title" => new WWW::Shopify::Field::String::Words(1, 3),
 	"handle" => new WWW::Shopify::Field::String::Handle(),
 	"commentable" => new WWW::Shopify::Field::String("(no|yes)"),
-	"tags" => new WWW::Shopify::Field::String(),
+	"tags" => new WWW::Shopify::Field::Text(),
 	"metafields" => new WWW::Shopify::Field::Relation::Many("WWW::Shopify::Model::Metafield"),
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"created_at" => new WWW::Shopify::Field::Date(),
