@@ -13,13 +13,13 @@ BEGIN { $fields = {
 	"id" => new WWW::Shopify::Field::Identifier(),
 	"name" => new WWW::Shopify::Field::String(),
 	"callback_url" => new WWW::Shopify::Field::String::URL(),
-	"format" => new WWW::Shopify::Field::String::Enum(["json", "xml"]),
 	"service_discovery" => new WWW::Shopify::Field::Boolean(),
 	"active" => new WWW::Shopify::Field::Boolean(),
+	"format" => new WWW::Shopify::Field::String::Enum(["json", "xml"]),
 	"carrier_service_type" => new WWW::Shopify::Field::String::Enum(["api"]),
 }; }
 
-sub creation_minimal { return qw(name callback_url format service_discovery); }
+sub creation_minimal { return qw(name callback_url service_discovery); }
 sub creation_filled { return qw(id active carrier_service_type); }
 
 sub read_scope { return "read_shipping"; }
