@@ -19,6 +19,7 @@ BEGIN { $fields = {
 	"key" => new WWW::Shopify::Field::String(),
 	"namespace" => new WWW::Shopify::Field::String(),
 	"value_type" => new WWW::Shopify::Field::String::Enum(["integer", "float", "string"]),
+	"type" => new WWW::Shopify::Field::String::Enum([qw(single_line_text_field multi_line_text_field page_reference product_reference variant_reference file_reference number_integer number_decimal date date_time url json boolean color weight volume dimension rating)]),
 	"value" => new WWW::Shopify::Field::MediumText()
 }; }
 
@@ -29,7 +30,7 @@ sub update_through_parent { return 1; }
 sub delete_through_parent { return undef; }
 sub included_in_parent { return undef; }
 
-sub creation_minimal { return qw(key namespace value_type value); }
+sub creation_minimal { return qw(key namespace value); }
 sub creation_filled { return qw(created_at id owner_resource); }
 sub update_filled { return qw(updated_at); }
 sub update_fields { return qw(description key namespace value_type value); }
